#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
#undef PACKAGE
#undef VERSION
#undef GNOME_ICON
#undef HAVE_ESD
#undef HAVE_SOCKS5
#undef TRACE_FUNCTION
#undef USE_STATUS_MENU
#undef HAVE_LIBGDBM
#undef HAVE_NDBM
#undef BUILD_APPLET
#undef USE_XSCREENSAVER
